<div style="text-align:center;"><img src="./pygeotools.png" /></div>

__pygeotools__ is a library allowing to load, manipulate and visualise _geomagnetic models_ stemming from assimilation tools such as:
- __CHAOS__ ([https://doi.org/10.1186/s40623-020-01252-9](https://doi.org/10.1186/s40623-020-01252-9))
- __KALMAG__ ([https://doi.org/10.1186/s40623-020-01295-y](https://doi.org/10.1186/s40623-020-01295-y))
- __COV-OBS.x2__ ([https://doi.org/10.1186/s40623-020-01194-2](https://doi.org/10.1186/s40623-020-01194-2))

and _observations_ stemming either from ground or virtual observatories, and is being developed at [ISTerre](https://www.isterre.fr/?lang=en) (Grenoble, France) by the Geodynamo team.

### How it works
<img src="./diagram.png" style="width: 500px;" />

### Installations

The `pygeotools` library is released as a package within the name `pygeodyntools` (to avoid confusion with already-existing packages). It can be installed using the `pip` command.

```bash
pip install pygeodyntools
```

### Documentation

See [docs/README.md](docs/README.md)

### License

The work is licensed under the [GNU GPLv3](LICENSE.txt).

### Contributors

- [Romain Claveau](https://orcid.org/0000-0001-5961-0370) (ISTerre)
- [Nicolas Gillet](https://orcid.org/0000-0002-2219-1026) (ISTerre)